@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 #----------------------------------------------------------------------------
 
@@ -17,6 +17,8 @@ my %commands = (
     'kvers'     => 'uname -r',
     'osname'    => 'uname -o',
     'archname'  => 'uname -m',
+
+    '_irix1'   => 'uname -R',   # IRIX specific
 );
 
 my %default = ();
@@ -177,6 +179,14 @@ sub get_info {
 sub _release_version {
     my $self = shift;
 
+    if($self->{info}{kname} =~ /irix/i) {
+        $self->{info}{osname}   = 'IRIX';
+        $self->{info}{oslabel}  = 'IRIX';
+        $self->{info}{is32bit}  = $self->{info}{kname} !~ /64/ ? 1 : 0;
+        $self->{info}{is64bit}  = $self->{info}{kname} =~ /64/ ? 1 : 0;
+        return;
+    }
+
     for my $label (keys %distributions) {
         for my $file (@{ $distributions{$label}->{files} }) {
             next    unless(-f $file);
@@ -275,8 +285,7 @@ There are no known bugs at the time of this release. However, if you spot a
 bug or are experiencing difficulties, that is not explained within the POD
 documentation, please send bug reports and patches to the RT Queue (see below).
 
-RT Queue -
-http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
+RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
 =head1 AUTHORS
 
