@@ -5,7 +5,7 @@ use warnings;
 use POSIX;
 
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 #----------------------------------------------------------------------------
 
@@ -203,7 +203,7 @@ If you spot a bug or are experiencing difficulties, that is not explained
 within the POD documentation, please send bug reports and patches to the RT 
 Queue (see below).
 
-RT Queue - http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
+RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
 =head1 AUTHORS
 
